@@ -499,7 +499,11 @@ class LegacyHic(Hic):
         return self.marginals() > 0
 
     def bias_vector(self):
-        return [row['bias'] for row in self.file.get_node('/', 'node_annot').iterrows()]
+        bias = [row['bias'] for row in self.file.get_node('/', 'node_annot').iterrows()]
+        if len(bias) == len(self.regions):
+            return np.array(bias)
+        else:
+            return np.repeat(1., len(self.regions))
 
 
 class HicEdgeFilter(with_metaclass(ABCMeta, MaskFilter)):
@@ -697,7 +701,7 @@ def ice_balancing(hic, tolerance=1e-2, max_iterations=500, whole_matrix=True,
                     if source != sink:
                         m[sink] += edges[i][2]
 
-                bias_vector *= m
+                bias_vector *= np.sqrt(m)
                 marginal_error = _marginal_error(m)
                 for i in range(len(edges)):
                     source = region_converter[edges[i][0]]
@@ -732,7 +736,7 @@ def ice_balancing(hic, tolerance=1e-2, max_iterations=500, whole_matrix=True,
                 if source != sink:
                     m[sink] += edges[i][2]
 
-            bias_vector *= m
+            bias_vector *= np.sqrt(m)
             marginal_error = _marginal_error(m)
 
             for i in range(len(edges)):
@@ -743,6 +747,10 @@ def ice_balancing(hic, tolerance=1e-2, max_iterations=500, whole_matrix=True,
             current_iteration += 1
             logger.debug("Iteration: %d, error: %lf" % (current_iteration, marginal_error))
 
+    with np.errstate(divide='ignore'):
+        bias_vector = 1/bias_vector
+    bias_vector[~np.isfinite(bias_vector)] = 0
+
     hic.region_data('bias', bias_vector)
     return bias_vector
 
@@ -961,4 +969,4 @@ def get_bias_vector(A, x0=None, tol=1e-06, delta=0.1, Delta=3, fl=0, high_precis
             logger.error(str(e))
             raise ValueError("Generic catch all warnings")
 
-    return x
\ No newline at end of file
+    return x
